#!/bin/bash
# SALOME V7_5_1 - Environnement file for the prerequisites and tools

export ROOT_SALOME="/home/E99639/Documents/Couplage/salome/Salome-V7_5_1-LGPL-x86_64"
export LC_NUMERIC=C

# To be sure to display icons in Gnome, we use the Gnome Configuration tool
gconfTool=`which gconftool-2`
if test -n "$gconfTool"; then
  $gconfTool --type boolean --set /desktop/gnome/interface/buttons_have_icons true
  $gconfTool --type boolean --set /desktop/gnome/interface/menus_have_icons true
fi

export SALOME_PLUGINS_PATH="${ROOT_SALOME}/plugins":${SALOME_PLUGINS_PATH}

if test ! -d "${ROOT_SALOME}/prerequisites"; then
  echo "=========================================="
  echo "Error: SALOME prerequisites path not found"
  echo "=========================================="
  exit 1
fi
export PREREQUISITES_ROOT_DIR="${ROOT_SALOME}/prerequisites"

if test ! -d "${ROOT_SALOME}/tools"; then
  echo "=================================="
  echo "Error: SALOME tools path not found"
  echo "=================================="
  exit 1
fi
export TOOLS_ROOT_DIR="${ROOT_SALOME}/tools"

export DEBIANFORSALOME=${PREREQUISITES_ROOT_DIR}/debianForSalome
export LD_LIBRARY_PATH=${DEBIANFORSALOME}/lib:/lib64:${LD_LIBRARY_PATH}

#------ tcl ------
export TCLDIR="${PREREQUISITES_ROOT_DIR}/Tcl_8513"   # export needed by Code_Aster
export PATH=${TCLDIR}/bin:$PATH
export LD_LIBRARY_PATH=${TCLDIR}/lib:$LD_LIBRARY_PATH
export TCL_LIBRARY=${TCLDIR}/lib/tcl8.5

#------ tk ------
export TKDIR="${PREREQUISITES_ROOT_DIR}/Tk_8513"   # export needed by Code_Aster
export PATH=${TKDIR}/bin:$PATH
export LD_LIBRARY_PATH=${TKDIR}/lib:$LD_LIBRARY_PATH
export TK_LIBRARY=${TKDIR}/lib/tk8.5

#------ python ------
export PYTHONHOME="${PREREQUISITES_ROOT_DIR}/Python_273"
export PYTHONSTARTUP=${PYTHONHOME}/pythonrc.py
export PYTHON_INCLUDE=${PYTHONHOME}/include/python2.7
export PATH=${PYTHONHOME}/bin:${PATH}
export LD_LIBRARY_PATH=${PYTHONHOME}/lib:${LD_LIBRARY_PATH}
# Temporary added for New Geom, to be removed after
# new geom environment variables have been made
# conform with SALOME variables
export PYTHON_ROOT_DIR=$PYTHONHOME

#------ sip ------
export SIP_ROOT_DIR="${PREREQUISITES_ROOT_DIR}/Sip_4142"
export PATH=${SIP_ROOT_DIR}/bin:${PATH}
export PYTHONPATH=${SIP_ROOT_DIR}/lib/python2.7/site-packages:${PYTHONPATH}
export LD_LIBRARY_PATH=${SIP_ROOT_DIR}/lib/python2.7/site-packages:${LD_LIBRARY_PATH}

#------ tix ------
export LD_LIBRARY_PATH="${TCLDIR}/lib/Tix8.4.3":$LD_LIBRARY_PATH

#------ omniORB ------
export OMNIORB_DIR="${PREREQUISITES_ROOT_DIR}/Omniorb_416"
export PATH=${OMNIORB_DIR}/bin:$PATH
export PYTHONPATH=${OMNIORB_DIR}/lib/python2.7/site-packages:${PYTHONPATH}
export LD_LIBRARY_PATH=$OMNIORB_DIR/lib:$LD_LIBRARY_PATH

#------ hdf5 ------
export HDF5HOME="${PREREQUISITES_ROOT_DIR}/Hdf5_1810"
export PATH=${HDF5HOME}/bin:$PATH
export LD_LIBRARY_PATH=${HDF5HOME}/lib:${LD_LIBRARY_PATH}
export HDF5_DISABLE_VERSION_CHECK=1

#------ Cmake -----------
export PATH="${PREREQUISITES_ROOT_DIR}/Cmake_28102/bin":$PATH

#------ CGNS Library ------
CGNSHOME=${PREREQUISITES_ROOT_DIR}/Cgnslib_3134
export PATH=${CGNSHOME}/bin:$PATH
export LD_LIBRARY_PATH=${CGNSHOME}/lib:${LD_LIBRARY_PATH}

#------ togl ------
export LD_LIBRARY_PATH="${TCLDIR}/lib/Togl1.7":$LD_LIBRARY_PATH

#------- setuptools ------
export SETUPTOOLS_ROOT_DIR="${PREREQUISITES_ROOT_DIR}/Setuptools_06c11"
export PATH=${SETUPTOOLS_ROOT_DIR}/bin:${PATH}
export PYTHONPATH=${SETUPTOOLS_ROOT_DIR}/lib/python2.7/site-packages:${PYTHONPATH}

#------- pygments ------
PYGMENTS_HOME="${PREREQUISITES_ROOT_DIR}/Pygments_15"
export PATH=${PYGMENTS_HOME}/bin:${PATH}
export PYTHONPATH=${PYGMENTS_HOME}/lib/python2.7/site-packages:${PYTHONPATH}

#------- docutils ------
export DOCUTILS_ROOT_DIR="${PREREQUISITES_ROOT_DIR}/Docutils_010"
export PATH=${DOCUTILS_ROOT_DIR}/bin:${PATH}
export PYTHONPATH=${DOCUTILS_ROOT_DIR}/lib/python2.7/site-packages:${PYTHONPATH}

#------ swig ------
export SWIG_ROOT_DIR="${PREREQUISITES_ROOT_DIR}/Swig_208"
export SWIG_LIB=${SWIG_ROOT_DIR}/share/swig/2.0.8
export PATH=${SWIG_ROOT_DIR}/bin:$PATH

#------ boost ---------
export BOOSTDIR="${PREREQUISITES_ROOT_DIR}/Boost_1520"  # For check_boost.m4
export BOOST_ROOT="$BOOSTDIR"   # For CGAL
export LD_LIBRARY_PATH=$BOOST_ROOT/lib:$LD_LIBRARY_PATH

#------ omniORBpy ------
export OMNIORBPY_DIR="${PREREQUISITES_ROOT_DIR}/Omniorbpy_36"
export PYTHONPATH=${OMNIORBPY_DIR}/lib/python2.7/site-packages:${PYTHONPATH}
export PYTHONPATH=${OMNIORBPY_DIR}/lib/python2.7/site-packages/omniidl_be:${PYTHONPATH}

#------ Lapack ------
export LAPACKDIR=${PREREQUISITES_ROOT_DIR}/Lapack_350
export LD_LIBRARY_PATH="$LAPACKDIR/lib":${LD_LIBRARY_PATH}

#------ Numpy ------
NUMPY_DIR="${PREREQUISITES_ROOT_DIR}/Numpy_181"
export PATH=${NUMPY_DIR}/bin:${PATH}
export PYTHONPATH=${NUMPY_DIR}/lib/python2.7/site-packages:${PYTHONPATH}

#------ graphviz ------
GRAPHVIZHOME="${PREREQUISITES_ROOT_DIR}/Graphviz_2380"
export PATH=${GRAPHVIZHOME}/bin:${PATH}
export LD_LIBRARY_PATH=${GRAPHVIZHOME}/lib/graphviz:${GRAPHVIZHOME}/lib:${LD_LIBRARY_PATH}

#------ doxygen ------
export DOXYGEN_ROOT_DIR="${PREREQUISITES_ROOT_DIR}/Doxygen_1831"
export PATH=${DOXYGEN_ROOT_DIR}/bin:${PATH}

#------- libxml2 -------
export LIBXML_DIR="${PREREQUISITES_ROOT_DIR}/Libxml2_290"
export PATH=${LIBXML_DIR}/bin:${PATH}
export LD_LIBRARY_PATH=${LIBXML_DIR}/lib:${LD_LIBRARY_PATH}
export PYTHONPATH=${LIBXML_DIR}/lib/python2.7/site-packages:${PYTHONPATH}
# Temporary added for New Geom, to be removed after
# new geom environment variables have been made
# conform with SALOME variables
export LIBXML2_ROOT_DIR=$LIBXML_DIR

#---------- libBatch -------------------
export LIBBATCH_ROOT_DIR="${TOOLS_ROOT_DIR}/Libbatch_V2_2_0"
export LD_LIBRARY_PATH=${LIBBATCH_ROOT_DIR}/lib:${LD_LIBRARY_PATH}
export PYTHONPATH=$LIBBATCH_ROOT_DIR/lib/python2.7/site-packages:${PYTHONPATH}

#------- jinja ------
export PYTHONPATH="${PREREQUISITES_ROOT_DIR}/Jinja_26/lib/python2.7/site-packages":${PYTHONPATH}

#------- sphinx ------
export SPHINX_ROOT_DIR="${PREREQUISITES_ROOT_DIR}/Sphinx_113"
export PATH=${SPHINX_ROOT_DIR}/bin:${PATH}
export PYTHONPATH=${SPHINX_ROOT_DIR}/lib/python2.7/site-packages:${PYTHONPATH}

#------ cppunit ------
export CPPUNIT_ROOT="${PREREQUISITES_ROOT_DIR}/Cppunit_1121"
export PATH=${CPPUNIT_ROOT}/bin:$PATH
export LD_LIBRARY_PATH=${CPPUNIT_ROOT}/lib:${LD_LIBRARY_PATH}

#------ TBB. ------
export LD_LIBRARY_PATH="${PREREQUISITES_ROOT_DIR}/Tbb_30/lib":${LD_LIBRARY_PATH}

#------ gl2ps ------
export GL2PS_INSTALL_DIR="${PREREQUISITES_ROOT_DIR}/Gl2ps_138"
export LD_LIBRARY_PATH=${GL2PS_INSTALL_DIR}/lib:$LD_LIBRARY_PATH

#------ freetype ------
FREETYPE_ROOT="${PREREQUISITES_ROOT_DIR}/Freetype_2411"
export PATH=${FREETYPE_ROOT}/bin:$PATH
export LD_LIBRARY_PATH=${FREETYPE_ROOT}/lib:${LD_LIBRARY_PATH}

#------ cas ------
export CASROOT="${PREREQUISITES_ROOT_DIR}/Occ_680p1"
export LD_LIBRARY_PATH=${CASROOT}/lib:${LD_LIBRARY_PATH}
# Variable for Foundation Classes :
export CSF_UnitsLexicon=${CASROOT}/src/UnitsAPI/Lexi_Expr.dat
export CSF_UnitsDefinition=${CASROOT}/src/UnitsAPI/Units.dat
# Variable for DataExchange :
export CSF_SHMessageStd=${CASROOT}/src/SHMessageStd
export CSF_SHMessage=${CASROOT}/src/SHMessage
export CSF_XSMessage=${CASROOT}/src/XSMessage
# Variable for Font :
export CSF_MDTVFontDirectory=${CASROOT}/src/FontMFT
export CSF_MDTVTexturesDirectory=${CASROOT}/src/Textures
# Needed for HYDRO module :
export CSF_StandardDefaults=${CASROOT}/src/StdResource
export CSF_PluginDefaults=${CASROOT}/src/StdResource
export CSF_StandardLiteDefaults=${CASROOT}/src/StdResource
export CSF_XmlOcafResource=${CASROOT}/src/XmlOcafResource
# Temporary added for New Geom, to be removed after
# new geom environment variables have been made
# conform with SALOME variables
export PATH=${CASROOT}:${PATH}

# ------ Qt -------------
export QTDIR="${PREREQUISITES_ROOT_DIR}/Qt_484"
export PATH=${QTDIR}/bin:$PATH
export QT_PLUGIN_PATH=${QTDIR}/plugins
export LD_LIBRARY_PATH=${QTDIR}/lib:${LD_LIBRARY_PATH}

#-------PyQt ----------
export PYQT_ROOT_DIR="${PREREQUISITES_ROOT_DIR}/Pyqt_496"
export PYQT_SIPS=${PYQT_ROOT_DIR}/share/sip
export PYUIC=${PYQT_ROOT_DIR}/bin/pyuic4
export PYTHONPATH=${PYQT_ROOT_DIR}/lib/python2.7/site-packages:${PYTHONPATH}
export PATH=${PYQT_ROOT_DIR}/bin:${PATH}

#------ qwt ------
export QWTHOME="${PREREQUISITES_ROOT_DIR}/Qwt_610" # pour PARAVIS
export QWT_INCLUDES=${QWTHOME}/include
export LD_LIBRARY_PATH=${QWTHOME}/lib:${LD_LIBRARY_PATH}

#------ ParaView ------
export PVHOME="${PREREQUISITES_ROOT_DIR}/Paraview_420p10"
export PATH=${PVHOME}/bin:$PATH
export PVVERSION=4.2
export PV_PLUGIN_PATH=$(readlink -f ${PVHOME}/lib/paraview-${PVVERSION}:${PV_PLUGIN_PATH})
export LD_LIBRARY_PATH=${PVHOME}/lib/paraview-${PVVERSION}:$LD_LIBRARY_PATH
export PYTHONPATH=${PVHOME}/lib/paraview-${PVVERSION}:${PYTHONPATH}
export PYTHONPATH=${PVHOME}/lib/paraview-${PVVERSION}/site-packages:${PYTHONPATH}
export PYTHONPATH=${PVHOME}/lib/paraview-${PVVERSION}/site-packages/vtk:${PYTHONPATH}

export PYTHONPATH=${PVHOME}/lib/paraview-${PVVERSION}/site-packages/paraview/vtk:${PYTHONPATH}

#------ Opencv ------
export LD_LIBRARY_PATH="${PREREQUISITES_ROOT_DIR}/Opencv_231/lib":${LD_LIBRARY_PATH}

#------ distribute -----------
export DISTRIBUTE_ROOT_DIR="${PREREQUISITES_ROOT_DIR}/Distribute_0628"
export PATH=${DISTRIBUTE_ROOT_DIR}/bin:${PATH}
export PYTHONPATH=${DISTRIBUTE_ROOT_DIR}/lib/python2.7/site-packages:${PYTHONPATH}

#------ med fichier ------
export MED3HOME="${TOOLS_ROOT_DIR}/Medfichier_308"
export PATH=${MED3HOME}/bin:${PATH}
export LD_LIBRARY_PATH=${MED3HOME}/lib:${LD_LIBRARY_PATH}
export PYTHONPATH=${MED3HOME}/lib/python2.7/site-packages:${PYTHONPATH}

#------ qscintilla ------
QSCINTILLA_DIR="${PREREQUISITES_ROOT_DIR}/Qscintilla_271"
export QSCINTILLA_INCLUDES=${QSCINTILLA_DIR}/include
export LD_LIBRARY_PATH=${QSCINTILLA_DIR}/lib:${LD_LIBRARY_PATH}

#------ pyparsing -----------
export PYPARSING_ROOT_DIR="${PREREQUISITES_ROOT_DIR}/Pyparsing_203"
export PYTHONPATH=${PYPARSING_ROOT_DIR}/lib/python2.7/site-packages:${PYTHONPATH}

#------- SMESH -------
SMESH_DIR=${PREREQUISITES_ROOT_DIR}/../modules/SMESH_V7_5_1
export PYTHONPATH=${SMESH_DIR}/share/salome/plugins/smesh/Verima:${PYTHONPATH}

# ------ MeshGems -------------
MESHGEMSHOME="${PREREQUISITES_ROOT_DIR}/Meshgems_138"

export PATH=${MESHGEMSHOME}/bin/Linux_64:$PATH
export LD_LIBRARY_PATH=${MESHGEMSHOME}/lib/Linux_64:${LD_LIBRARY_PATH}

#------- h5py ------
export PYTHONPATH=${PREREQUISITES_ROOT_DIR}/H5py_211/lib/python2.7/site-packages:${PYTHONPATH}

# ------ Scipy ------
export PYTHONPATH="${PREREQUISITES_ROOT_DIR}/Scipy_0133/lib/python2.7/site-packages":${PYTHONPATH}

#------ EficasV1 -----------
export EFICAS_ROOT="${TOOLS_ROOT_DIR}/Eficasv1_V7_5_1"

#------ Metis ------
export METISDIR="${PREREQUISITES_ROOT_DIR}/Metis_40"
export LD_LIBRARY_PATH=${METISDIR}/Lib:${LD_LIBRARY_PATH}

#------ Scotch ------
export SCOTCHDIR="${PREREQUISITES_ROOT_DIR}/Scotch_5111"    # export needed for compilation of medsplitter/partitionner
export PATH=${SCOTCHDIR}/bin:${PATH}

#------- Paravis ------
export PARAVIS_DIR=${PREREQUISITES_ROOT_DIR}/../modules/PARAVIS_V7_5_1
export PV_PLUGIN_PATH="${PARAVIS_DIR}/lib/paraview:${PV_PLUGIN_PATH}"

#---------- netgen -------------------
export NETGENHOME="${TOOLS_ROOT_DIR}/Netgen_4913"
export LD_LIBRARY_PATH=${NETGENHOME}/lib:${LD_LIBRARY_PATH}

#---------- Homard -------------------
export HOMARD_REP_EXE="${TOOLS_ROOT_DIR}/Homard_tool_112"
export HOMARD_EXE=homard

#------ tornado -----------
export TORNADO_ROOT_DIR="${PREREQUISITES_ROOT_DIR}/Tornado_40"
export PYTHONPATH=${TORNADO_ROOT_DIR}/lib/python2.7/site-packages:${PYTHONPATH}

#------ python_dateutil -----------
export PYTHON_DATEUTIL_ROOT_DIR="${PREREQUISITES_ROOT_DIR}/Python_dateutil_23"
export PYTHONPATH=${PYTHON_DATEUTIL_ROOT_DIR}/lib/python2.7/site-packages:${PYTHONPATH}

#------- Matplotlib ------
export MATPLOTLIB_HOME="${PREREQUISITES_ROOT_DIR}/Matplotlib_131"
export PYTHONPATH=${MATPLOTLIB_HOME}/lib/python2.7/site-packages:${PYTHONPATH}
export MPLCONFIGDIR="${HOME}/.config/salome/matplotlib-1.3.1" # Useful to avoid changing the config files used by the system matplotlib

#---------- Xdata -------------------
export XDATA_ROOT_DIR="${TOOLS_ROOT_DIR}/Xdata_098"
export PATH=$XDATA_ROOT_DIR/bin:$PATH
export PYTHONPATH=$XDATA_ROOT_DIR/lib/python2.7/site-packages/xdata:${PYTHONPATH}
